@@ -223,11 +223,37 @@ class Form:
         return [accordion]
 
     def _construct_object(self, schema, label=None, root=False):
-        # Construct form elements for all the fields
+        # Construct form elements for all the fields, including some that are
+        # added through 'if'-'then' rules. This maps key -> FormElement
         elements = {}
+
+        # Store the conditional information from the schema in the following form:
+        # [(schema, cprop, element), ..]
+        # with the following meaning:
+        #   schema: The schema that the data needs to match
+        #   cprop: The property that is maybe added
+        #   element: The subelement for the property
+        conditionals = []
         for prop, subschema in schema["properties"].items():
             elements[prop] = self._construct(subschema, label=prop)
 
+        # Add conditional elements
+        def add_conditional_elements(s):
+            # Check whether we have an if statement
+            cond = s.get("if", None)
+            if cond is None:
+                return
+
+            for cprop, csubschema in s.get("then", {}).get("properties", {}).items():
+                celem = self._construct(csubschema, label=cprop)
+                conditionals.append((cond, cprop, celem))
+                elements[cprop] = celem
+
+            if "else" in s:
+                add_conditional_elements(s["else"])
+
+        add_conditional_elements(schema)
+
         # Apply sorting to the keys
         keys = schema["properties"].keys()
         try:
@@ -236,13 +262,38 @@ class Form:
             # If the keys cannot be compared, we stick to the original order
             pass
 
-        # If this is not the root document, we wrap this in an Accordion widget
+        # Collect the list of widgets: First the regular ones, then conditional ones
         widget_list = sum((elements[k].widgets for k in keys), [])
+        widget_list.extend(
+            [
+                ipywidgets.HBox(layout=ipywidgets.Layout(width="100%"))
+                for _ in range(len(conditionals))
+            ]
+        )
+
+        # Maybe wrap this in an Accordion widget
+        wrapped_widget_list = widget_list
         if not root:
-            widget_list = self._wrap_accordion(widget_list, schema, label=label)
+            wrapped_widget_list = self._wrap_accordion(widget_list, schema, label=label)
+
+        def _getter():
+            # Get all regular properties
+            result = {}
+            for k in schema["properties"].keys():
+                result[k] = elements[k].getter()
+
+            # Add conditional properties
+            for cschema, cprop, celem in conditionals:
+                try:
+                    jsonschema.validate(instance=result, schema=cschema)
+                    result[cprop] = celem.getter()
+                except jsonschema.ValidationError:
+                    pass
+
+            return result
 
         def _setter(_d):
-            for k in schema["properties"].keys():
+            for k in elements.keys():
                 if k in _d:
                     elements[k].setter(_d[k])
                 else:
@@ -256,11 +307,39 @@ class Form:
             for e in elements.values():
                 e.resetter()
 
+        # Add the conditional information
+        for i, (cschema, cprop, celem) in enumerate(conditionals):
+
+            def create_observer(j, s, prop, e):
+                def _cond_observer(_):
+                    # Check whether our data matches the given schema
+                    try:
+                        jsonschema.validate(instance=_getter(), schema=s)
+                        elements[prop] = e
+                        widget_list[len(keys) + j].children = e.widgets
+                    except jsonschema.ValidationError:
+                        widget_list[len(keys) + j].children = []
+
+                # We need to call the observer once so that we get a correctly
+                # initialized widget, because otherwise it triggers only if it
+                # differs from the default.
+                _cond_observer({})
+
+                return _cond_observer
+
+            for k in cschema.get("properties", {}).keys():
+                elements[k].register_observer(
+                    create_observer(i, cschema, cprop, celem), "value", "change"
+                )
+
+        # Ensure that defaults are initialized
+        _resetter()
+
         return self.construct_element(
-            getter=lambda: {p: e.getter() for p, e in elements.items()},
+            getter=_getter,
             setter=_setter,
             resetter=_resetter,
-            widgets=widget_list,
+            widgets=wrapped_widget_list,
             subelements=elements,
             register_observer=_register_observer,
         )
@@ -300,7 +379,7 @@ class Form:
         # Apply regex pattern matching
         def pattern_checker(val):
             # This only makes sense for strings
-            if schema["type"] != "string":
+            if schema["type"] != "string" or val is None:
                 return True
 
             # Try matching the given data against the pattern
